@@ -36,6 +36,10 @@ class FiniteAutomaton(ABC):
     def alphabet(self) -> Alphabet:
         return self._alphabet
 
+    @property
+    def output_alphabet(self):
+        return [True, False]
+
     @property
     @abstractmethod
     def hole(self):
